{
  inputs = {
    nixpkgs.url = github:NixOS/nixpkgs/nixos-22.05;

    home-manager = {
      url = github:nix-community/home-manager/release-22.05;
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = inputs @ { self, nixpkgs, home-manager, ... }:
    let
      user = "mandlm";
      theme = "dark";       # dark or light
    in
    {
      nixosConfigurations = {
        nixos-vm = nixpkgs.lib.nixosSystem {
          system = "x86_64-linux";
          specialArgs = inputs;
          modules = [
            ./configuration.nix
            ./users.nix
            ./machines/nixos-vm/configuration.nix
            ./machines/nixos-vm/hardware-configuration.nix

            home-manager.nixosModules.home-manager
            {
              home-manager.useGlobalPkgs = true;
              home-manager.useUserPackages = true;
              home-manager.extraSpecialArgs = { inherit user theme; };
              home-manager.users.${user} = {
                imports = [ ./home-${user}.nix ];
              };
            }
          ];
        };

        apache = nixpkgs.lib.nixosSystem {
          system = "x86_64-linux";
          specialArgs = inputs;
          modules = [
            ./configuration.nix
            ./users.nix
            ./machines/apache/configuration.nix
            ./machines/apache/hardware-configuration.nix

            home-manager.nixosModules.home-manager
            {
              home-manager.useGlobalPkgs = true;
              home-manager.useUserPackages = true;
              home-manager.extraSpecialArgs = { inherit user theme; };
              home-manager.users.${user} = {
                imports = [
                  ./home-${user}.nix
                  ./machines/apache/home-${user}.nix
                ];
              };
            }
          ];
        };

        p330 = nixpkgs.lib.nixosSystem {
          system = "x86_64-linux";
          specialArgs = inputs;
          modules = [
            ./configuration.nix
            ./users.nix
            ./machines/p330/configuration.nix
            ./machines/p330/hardware-configuration.nix

            home-manager.nixosModules.home-manager
            {
              home-manager.useGlobalPkgs = true;
              home-manager.useUserPackages = true;
              home-manager.extraSpecialArgs = { inherit user theme; };
              home-manager.users.${user} = {
                imports = [
                  ./home-${user}.nix
                  ./machines/p330/home-${user}.nix
                ];
              };
            }
          ];
        };

        yoga = nixpkgs.lib.nixosSystem {
          system = "x86_64-linux";
          specialArgs = inputs;
          modules = [
            ./configuration.nix
            ./users.nix
            ./machines/yoga/configuration.nix
            ./machines/yoga/hardware-configuration.nix
            ./machines/yoga/users.nix

            home-manager.nixosModules.home-manager
            {
              home-manager.useGlobalPkgs = true;
              home-manager.useUserPackages = true;
              home-manager.extraSpecialArgs = { inherit user theme; };
              home-manager.users.${user} = {
                imports = [
                  ./home-${user}.nix
                  ./machines/yoga/home-${user}.nix
                ];
              };
              home-manager.users.scf = {
                imports = [
                  ./machines/yoga/home-scf.nix
                ];
              };
            }
          ];
        };
      };
    };
}
